<?php
/**
 * Dynamic CSS for the frontend.
 *
 * @package Scribbler
 */

defined( 'WPINC' ) || exit;

/**
 * Helper function.
 * Merge and combine the CSS elements.
 *
 * @param  string|array $elements An array of our elements.
 *                                If we use a string then it is directly returned.
 * @return string
 */
function scribbler_implode( $elements = array() ) {

	if ( ! is_array( $elements ) ) {
		return $elements;
	}

	// Make sure our values are unique.
	$elements = array_unique( $elements );

	// Sort elements alphabetically.
	// This way all duplicate items will be merged in the final CSS array.
	sort( $elements );

	// Implode items and return the value.
	return implode( ',', $elements );

}

/**
 * Maps elements from dynamic css to the selector.
 *
 * @param  array  $elements The elements.
 * @param  string $selector The selector.
 * @return array
 */
function scribbler_map_selector( $elements, $selector ) {
	$array = array();

	foreach ( $elements as $element ) {
		$array[] = $element . $selector;
	}

	return $array;
}

/**
 * Map CSS selectors from values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function scribbler_map_css_selectors( &$css, $values ) {
	if ( isset( $values['css-selectors'] ) ) {
		$elements = $values['css-selectors'];
		unset( $values['css-selectors'] );

		$css[ $elements ] = $values;
	}
}

/**
 * Merge CSS values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function scribbler_merge_value( &$css, $values ) {
	foreach ( $values as $id => $val ) {
		$css[ $id ] = $val;
	}
}

/**
 * Format of the $css array:
 * $css['media-query']['element']['property'] = value
 *
 * If no media query is required then set it to 'global'
 *
 * If we want to add multiple values for the same property then we have to make it an array like this:
 * $css[media-query][element]['property'][] = value1
 * $css[media-query][element]['property'][] = value2
 *
 * Multiple values defined as an array above will be parsed separately.
 */
function scribbler_dynamic_css_array() {

	global $wp_version;

	$css       = array();
	$c_page_id = scribbler()->get_page_id();

	// Site Background.
	$css['global']['html body'] = Scribbler_Sanitize::background( scribbler_get_settings( 'mts_background' ) );

	// Top bar Background.
	$css['global']['.top-bar'] = Scribbler_Sanitize::background( scribbler_get_settings( 'top_bar_background' ) );

	// Header Background.
	$css['global']['.main-header, .main-header.sticky-navigation-active #header, .navigation ul ul'] = Scribbler_Sanitize::background( scribbler_get_settings( 'header_background' ) );

	// Logo Font.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'scribbler_logo' ) ) );
	// Primary Navigation font.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'primary_navigation_font' ) ) );
	// Content Font.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'pages_title_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'content_font' ) ) );
	// Pagination.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'pagination_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'loadmore_font' ) ) );
	// Archive Pages font.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'archive_post_title_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'archive_post_excerpt_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'archive_meta_info_upper_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'archive_post_categories_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'archive_meta_info_bottom_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'archive_readmore_font' ) ) );
	$elements = array(
		'.archive .latestPost .post-info-upper .thecategory a',
		'.search .latestPost .post-info-upper .thecategory a',
	);
	$css['global'][ scribbler_implode( $elements ) ]['background-color'] = Scribbler_Sanitize::color( scribbler_get_settings( 'archive_post_categories_bg' ) );
	// Breadcrumbs font.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'breadcrumb_font' ) ) );
	// Single post title font.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'single_title_font' ) ) );
	// Single post author info font.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'single_author_meta_info_font' ) ) );
	// Single Page titles font.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'single_page_titles_font' ) ) );
	// Single subscribe box.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'single_subscribe_title_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'single_subscribe_text_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'single_subscribe_input_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'single_subscribe_submit_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'single_subscribe_small_text_font' ) ) );
	// Author Box.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'authorbox_title_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'authorbox_author_name_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'authorbox_text_font' ) ) );
	// Sidebar widget title font.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'sidebar_title_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'sidebar_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'sidebar_links_widgets' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'sidebar_post_title' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'sidebar_big_post_title' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'sidebar_postinfo_font' ) ) );
	// Footer widget title font.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'top_footer_title_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'top_footer_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'footer_links_widgets' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'top_footer_post_title' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'footer_big_post_title' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'top_footer_meta_font' ) ) );
	// Copyrights section font.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'copyrights_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'footer_nav_font' ) ) );
	// H1 title in the content.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'h1_headline' ) ) );
	// H2 title in the content.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'h2_headline' ) ) );
	// H3 title in the content.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'h3_headline' ) ) );
	// H4 title in the content.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'h4_headline' ) ) );
	// H5 title in the content.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'h5_headline' ) ) );
	// H6 title in the content.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'h6_headline' ) ) );

	// Footer background.
	$css['global']['#site-footer'] = Scribbler_Sanitize::background( scribbler_get_settings( 'mts_footer_background' ) );

	scribbler_dynamic_css_skin( $css );
	scribbler_sidebar_position( $css );
	scribbler_header( $css );
	scribbler_sidebar_styling( $css );
	scribbler_pages_title( $css );
	scribbler_post_layouts( $css );
	scribbler_post_pagination( $css );
	scribbler_footer( $css );
	scribbler_copyrights( $css );
	scribbler_single( $css );
	scribbler_single_social_buttons( $css );
	scribbler_archive_post( $css );
	scribbler_misc_css( $css );

	return apply_filters( 'scribbler_dynamic_css_array', $css );
}

/**
 * Skin CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function scribbler_dynamic_css_skin( &$css ) {

	// Colors.
	$primary_color_scheme = Scribbler_Sanitize::color( scribbler_get_settings( 'primary_color_scheme' ) );

	$dark_color  = color_luminance( $primary_color_scheme, -0.2 );
	$light_color = color_luminance( $primary_color_scheme, 0.2 );

	// Text Color.
	$elements = array(
		'a',
		'body a:hover',
		'.reply a',
		'.latestPost .title a:hover',
		'.related-posts .title a:hover',
		'.layout-default .latestPost .title a:hover',
		'.layout-1 .latestPost .title a:hover',
		'.woocommerce ul.products li.product .price',
		'.product_list_widget .amount',
		'.woocommerce div.product p.price, .woocommerce div.product span.price',
		'.shareit-circular.standard .fa:hover',
		'.textwidget a',
		'#wp-calendar td#today',
		'.pnavigation2 a',
		'#sidebar .widget li a:hover',
		'.title a:hover',
		'#sidebar .widget li.horizontal-small .post-title a:hover',
		'#tabber .inside li a:hover',
		'.fn a',
		'.post-info a:hover',
		'.related-posts .title a:hover',
		'blockquote:after',
		'article ul li::before',
		'.single .pagination a .current:hover',
		'blockquote::before',
		'.postauthor h5 a:hover',
		'#primary-navigation li:hover > a',
		'.toggle-menu .toggle-caret .fa',
		'#primary-navigation li.current-menu-item a',
		'.layout-grid .latestPost .title a:hover',
		'.tags a',
		'#sidebar .widget.widget_tag_cloud a',
		'.widget .wpt_widget_content #tags-tab-content ul li a',
		'#sidebar .widget .post-info .thecategory a',
		'.shareit-circular.standard .share-text',
		'a#pull:hover',
		'.single-author-posts h3.title a:hover',
		'.f-widget .widget li.horizontal-small .post-title a:hover',
		'#copyright-note a:hover',
		'#sidebar .widget a:hover',
		'li.no-thumb.horizontal-small',
		'.single-subscribe .widget #wp-subscribe input.submit',
		'#site-footer .widget.widget_archive a:hover',
		'#site-footer .widget.widget_categories a:hover',
		'#site-footer .widget.widget_pages a:hover',
		'#site-footer .widget.widget_tag_cloud a:hover',
		'#site-footer .widget.widget_meta a:hover',
		'#site-footer .widget.widget_nav_menu a:hover',
		'.f-widget .aboutme-widget .aboutme-social a:hover',
		'#site-footer .vertical-small .post-title a:hover',
		'#site-footer .wpt_thumb_large + .entry-title a:hover',
		'#site-footer .review_thumb_large .entry-title a:hover',
		'#site-footer .post-title a:hover',
		'#site-footer .entry-title a:hover',
		'.ajax-search-results li a:hover',
		'.related-posts .post-info a:hover',
	);

	$css['global'][ scribbler_implode( $elements ) ]['color'] = $primary_color_scheme;
	//social svg hover color
	$css['global']['.shareit-circular.standard svg:hover']['fill'] = $primary_color_scheme;

	// Text Color Important.
	$elements = array(
		'.widget .review_thumb_large .review-result',
		'.widget .review_thumb_large .review-total-only.large-thumb',
		'.review-total-only.small-thumb .review-result-wrapper i',
		'.theauthor a:hover',
		'.readMore a:hover',
		'.widget .wpt_widget_content .wpt-pagination a:hover',
	);
	$css['global'][ scribbler_implode( $elements ) ]['color'] = $primary_color_scheme . '!important';

	// Background Color.
	$elements = array(
		'.pace .pace-progress',
		'#mobile-menu-wrapper ul li a:hover',
		'.navigation #wpmm-megamenu .wpmm-pagination a',
		'.wpmm-megamenu-showing.wpmm-light-scheme',
		'.widget #wp-subscribe input.submit',
		'#move-to-top:hover',
		'#tabber ul.tabs li a.selected',
		'.navigation ul .sfHover a',
		'.widget-slider .slide-caption',
		'.owl-prev:hover, .owl-next:hover',
		'.widget .wp-subscribe-wrap h4.title span.decor:after',
		'.woocommerce a.button',
		'.woocommerce-page a.button',
		'.woocommerce button.button',
		'.woocommerce-page button.button',
		'.woocommerce input.button',
		'.woocommerce-page input.button',
		'.woocommerce #respond input#submit',
		'.woocommerce-page #respond input#submit',
		'.woocommerce #content input.button',
		'.woocommerce-page #content input.button',
		'.woocommerce .bypostauthor:after',
		'.woocommerce a.button',
		'.woocommerce-page a.button',
		'.woocommerce button.button',
		'.woocommerce-page button.button',
		'.woocommerce input.button',
		'.woocommerce-page input.button',
		'.woocommerce #respond input#submit',
		'.woocommerce-page #respond input#submit',
		'.woocommerce #content input.button',
		'.woocommerce-page #content input.button',
		'.woocommerce #respond input#submit.alt.disabled',
		'.woocommerce #respond input#submit.alt.disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled',
		'.woocommerce #respond input#submit.alt:disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled[disabled]',
		'.woocommerce #respond input#submit.alt:disabled[disabled]:hover',
		'.woocommerce a.button.alt.disabled, .woocommerce a.button.alt.disabled:hover',
		'.woocommerce a.button.alt:disabled',
		'.woocommerce a.button.alt:disabled:hover',
		'.woocommerce a.button.alt:disabled[disabled]',
		'.woocommerce a.button.alt:disabled[disabled]:hover',
		'.woocommerce button.button.alt.disabled',
		'.woocommerce button.button.alt.disabled:hover',
		'.woocommerce button.button.alt:disabled',
		'.woocommerce button.button.alt:disabled:hover',
		'.woocommerce button.button.alt:disabled[disabled]',
		'.woocommerce button.button.alt:disabled[disabled]:hover',
		'.woocommerce input.button.alt.disabled',
		'.woocommerce input.button.alt.disabled:hover',
		'.woocommerce input.button.alt:disabled',
		'.woocommerce input.button.alt:disabled:hover',
		'.woocommerce input.button.alt:disabled[disabled]',
		'.woocommerce input.button.alt:disabled[disabled]:hover',
		'#wpmm-megamenu .review-total-only',
		'#searchsubmit',
		'#add_payment_method .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce-cart .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce #respond input#submit.alt',
		'.woocommerce a.button.alt',
		'.woocommerce button.button.alt',
		'.woocommerce input.button.alt',
		'.woocommerce-account .woocommerce-MyAccount-navigation li.is-active',
		'.woocommerce .woocommerce-widget-layered-nav-dropdown__submit',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-handle',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-range',
		'.woocommerce nav.woocommerce-pagination ul li a:focus',
		'.woocommerce nav.woocommerce-pagination ul li a:hover',
		'.woocommerce nav.woocommerce-pagination ul li span.current',
		'.latestPost-review-wrapper',
		'.latestPost .review-type-circle.latestPost-review-wrapper',
		'.woocommerce span.onsale',
		'.widget .widget_wp_review_tab .review-total-only.large-thumb',
		'.button:hover',
		'.breadcrumb .separator',
		'.post-info > span::after',
		'#wp-calendar caption',
		'.button',
		'.instagram-button a',
		'.widget_product_search button[type="submit"]',
		'.tags a:hover',
		'.error404 .article .sbutton',
		'.search .article .sbutton',
		'#commentform input#submit',
		'#mtscontact_submit',
		'#primary-navigation li a:before',
		'#sidebar .widget .tagcloud a:hover',
		'.f-widget .tagcloud a:hover',
		'.widget .wpt_widget_content #tags-tab-content ul li a:hover',
		'.widget .wp_review_tab_widget_content ul.wp-review-tabs li.selected a::before',
		'.widget .wpt_widget_content ul.wpt-tabs li.selected a::before',
		'.widget #wp-subscribe input.consent-field:after',
		'.widget .sbutton',
	);

	$css['global'][ scribbler_implode( $elements ) ]['background-color']                                = $primary_color_scheme;
	$css['@media screen and (max-width: 865px)']['.navigation.mobile-menu-wrapper']['background-color'] = $primary_color_scheme;

	// Background Color Important.
	$elements = array(
		'.widget .wpt_widget_content #tags-tab-content ul li a:hover',
	);
	$css['global'][ scribbler_implode( $elements ) ]['background-color'] = $primary_color_scheme . '!important';

	// Border Color.
	$elements = array(
		'.tags a:hover',
		'.tags a',
		'.tagcloud a',
		'.widget .wpt_widget_content #tags-tab-content ul li a',
		'.widget #wp-subscribe input.submit',
	);
	$css['global'][ scribbler_implode( $elements ) ]['border-color'] = $primary_color_scheme;

	// Text Color Important.
	$elements = array(
		'#commentform input#submit:hover',
		'.widget_product_search button[type="submit"]:hover',
		'.button:hover',
		'.instagram-button a:hover',
		'.widget_product_search button[type="submit"]:hover',
		'#mtscontact_submit:hover',
		'.widget #wp-subscribe input.submit:hover',
		'.widget .sbutton:hover',
	);
	$css['global'][ scribbler_implode( $elements ) ]['background'] = $dark_color;

	$elements = array(
		'.sticky-navigation-active #header',
	);
	$css['global'][ scribbler_implode( $elements ) ]['background'] = $light_color;

}

/**
 * Sidebar Position
 *
 * @param array $css Array of dynamic CSS.
 */
function scribbler_sidebar_position( &$css ) {

	// Sidebar position.
	$sidebar_position = scribbler_get_settings( 'mts_layout' );

	$sidebar_metabox_location = '';
	if ( is_page() || is_single() ) {
		$sidebar_metabox_location = get_post_meta( get_the_ID(), '_mts_sidebar_location', true );
	}

	if ( 'right' !== $sidebar_metabox_location && ( 'sclayout' === $sidebar_position || 'left' === $sidebar_metabox_location ) ) {
		$css['global']['.article']['float']                = 'right';
		$css['global']['.sidebar.c-4-12']['float']         = 'left';
		$css['global']['.sidebar.c-4-12']['padding-right'] = 0;

		if ( null !== scribbler_get_settings( 'mts_social_button_position' ) && 'floating' === scribbler_get_settings( 'mts_social_button_position' ) ) {

			$shareit_class = array(
				'.right .shareit.shareit-default.floating',
				'.right .shareit.standard.floating',
				'.right .shareit.shareit-circular.floating',
			);

			$css['global'][ scribbler_implode( $shareit_class ) ]['left']  = 'auto';
			$css['global'][ scribbler_implode( $shareit_class ) ]['right'] = '0px';

			$css['global'][ scribbler_implode( $shareit_class ) ]['margin-left']  = '0px';
			$css['global'][ scribbler_implode( $shareit_class ) ]['margin-right'] = '50px';
		}
	}
	if ( 'mts_nosidebar' == mts_custom_sidebar() ) {
		$css['global']['.single-full-header']['width'] = '100%';
	}
}

/**
 * Header
 *
 * @param array $css Array of dynamic CSS.
 */
function scribbler_header( &$css ) {

	$header_styles = scribbler_get_settings( 'header_styles' );
	$header_icons  = scribbler_get_settings( 'header_social_icons' );

	// Header.
	$header_class = array(
		'#header',
	);
	scribbler_merge_value( $css['global'][ scribbler_implode( $header_class ) ], Scribbler_Sanitize::margin( scribbler_get_settings( 'header_margin' ) ) );
	scribbler_merge_value( $css['global'][ scribbler_implode( $header_class ) ], Scribbler_Sanitize::padding( scribbler_get_settings( 'header_padding' ) ) );

	// Header Border.
	$header_border = Scribbler_Sanitize::border( scribbler_get_settings( 'header_border' ) );
	$css['global'][ scribbler_implode( $header_class ) ][ $header_border['direction'] ] = $header_border ['value'];

	// Nav styling.
	// Nav color.
	$css['global']['#primary-navigation .navigation ul ul a']['color']            = Scribbler_Sanitize::color( scribbler_get_settings( 'main_navigation_dropdown_color' ) );
	$css['global']['#primary-navigation .navigation ul ul']['background']         = Scribbler_Sanitize::color( scribbler_get_settings( 'main_navigation_dropdown_background' ) );
	$css['global']['#primary-navigation .navigation ul ul li:hover > a']['color'] = Scribbler_Sanitize::color( scribbler_get_settings( 'main_navigation_dropdown_hover_color' ) );

	// Social icons.
	if ( ! empty( $header_icons ) && is_array( $header_icons ) ) :
		foreach ( $header_icons as $header_icon ) :
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['background-color']            = Scribbler_Sanitize::color( $header_icon['header_icon_bgcolor'] );
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] . ':hover' ]['background-color'] = Scribbler_Sanitize::color( $header_icon['header_icon_hover_bgcolor'] );
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['color']                       = Scribbler_Sanitize::color( $header_icon['header_icon_color'] );
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] . ':hover' ]['color']            = Scribbler_Sanitize::color( $header_icon['header_icon_hover_color'] );
			scribbler_merge_value( $css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ], Scribbler_Sanitize::margin( $header_icon['header_icon_margin'] ) );
			scribbler_merge_value( $css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ], Scribbler_Sanitize::padding( $header_icon['header_icon_padding'] ) );
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['border-radius'] = Scribbler_Sanitize::size( $header_icon['header_icon_border_radius'] . 'px' );
		endforeach;
	endif;

	$buttons = scribbler_get_settings( 'header_buttons' );
	$i       = 0;
	if ( ! empty( $buttons ) && is_array( $buttons ) ) {
		foreach ( $buttons as $button ) {
			++$i;
			$css['global'][ '.header-button.button-' . $i . ' .button' ]['color']            = Scribbler_Sanitize::color( $button['button_text_color'] );
			$css['global'][ '.header-button.button-' . $i . ' .button' ]['background']       = Scribbler_Sanitize::color( $button['button_bg_color'] );
			$css['global'][ '.header-button.button-' . $i . ' .button:hover' ]['color']      = Scribbler_Sanitize::color( $button['button_text_hover_color'] );
			$css['global'][ '.header-button.button-' . $i . ' .button:hover' ]['background'] = Scribbler_Sanitize::color( $button['button_bg_hover_color'] );
			$css['global'][ '.header-button.button-' . $i . ' .button' ]['border-radius']    = Scribbler_Sanitize::size( $button['button_border_radius'] . 'px' );
			if ( ! isset( $button['button_box_shadow'] ) ) :
				$css['global'][ '.header-button.button-' . $i . ' .button' ]['box-shadow'] = 'none';
			endif;
		}
	}

	// Header Ad.
	scribbler_merge_value( $css['global']['.widget-header, .small-header .widget-header'], Scribbler_Sanitize::margin( scribbler_get_settings( 'mts_header_adcode_margin' ) ) );

	// Ad-Blocker.
	$css['global']['.navigation-banner']['background'] = Scribbler_Sanitize::color( scribbler_get_settings( 'navigation_ad_background' ) );

	// Floating Navigation Responsive
	if ( ! scribbler_get_settings( 'sticky_responsive_nav' ) ) :
		$css['@media screen and (max-width: 865px)']['#catcher']['height']                           = '0px!important';
		$css['@media screen and (max-width: 865px)']['.sticky-navigation-active']['position']        = 'relative!important';
		$css['@media screen and (max-width: 865px)']['.sticky-navigation-active']['top']             = '0px!important';
		$css['@media screen and (max-width: 865px)']['.admin-bar .sticky-navigation-active ']['top'] = '0px!important';
	endif;
}

/**
 * Social Share Styling
 *
 * @param array $css Array of dynamic CSS.
 */
function scribbler_single_social_buttons( &$css ) {

	// Social share.
	$css['global']['.shareit.floating'] = Scribbler_Sanitize::background( scribbler_get_settings( 'social_styling_background' ) );
	scribbler_merge_value( $css['global']['.shareit.floating'], Scribbler_Sanitize::margin( scribbler_get_settings( 'social_styling_margin' ) ) );

	// Social share border.
	$social_border = Scribbler_Sanitize::border( scribbler_get_settings( 'social_styling_border' ) );
	$css['global']['.shareit.floating'][ $social_border ['direction'] ] = $social_border ['value'];

	$social_button_layout   = scribbler_get_settings( 'social_button_layout' );
	$social_button_position = scribbler_get_settings( 'social_floating_button_position' );
	if ( 'default' === $social_button_layout ) {
		$share_class = '.shareit.shareit-' . $social_button_layout . '.floating';
	} else {
		$share_class = '.shareit.' . $social_button_layout . '.floating';
	}
	if ( ! empty( $social_button_position ) && is_array( $social_button_position ) ) {
		foreach ( $social_button_position as $key => $position ) {
			$css['global'][ $share_class ][ $key ] = $position;
		}
	}
}

/**
 * Sidebar styling
 *
 * @param array $css Array of dynamic CSS.
 */
function scribbler_sidebar_styling( &$css ) {

	// Sidebar.
	scribbler_merge_value( $css['global']['.sidebar .widget'], Scribbler_Sanitize::background( scribbler_get_settings( 'sidebar_styling_background' ) ) );
	scribbler_merge_value( $css['global']['.sidebar .widget'], Scribbler_Sanitize::margin( scribbler_get_settings( 'sidebar_styling_margin' ) ) );
	scribbler_merge_value( $css['global']['.sidebar .widget'], Scribbler_Sanitize::padding( scribbler_get_settings( 'sidebar_styling_padding' ) ) );
	$css['global']['.sidebar .widget']['border-radius'] = Scribbler_Sanitize::size( scribbler_get_settings( 'sidebar_styling_border_radius' ) . 'px' );
	if ( empty( scribbler_get_settings( 'sidebar_styling_box_shadow' ) ) ) :
		$css['global']['.sidebar .widget']['box-shadow'] = 'none';
	endif;

	// Sidebar border.
	$sidebar_border = Scribbler_Sanitize::border( scribbler_get_settings( 'sidebar_styling_border' ) );
	$css['global']['.sidebar .widget'][ $sidebar_border['direction'] ] = $sidebar_border['value'];

	// Sidebar title.
	$sidebar_title                   = '#sidebar .widget h3';
	$css['global'][ $sidebar_title ] = Scribbler_Sanitize::background( scribbler_get_settings( 'sidebar_title_styling_background' ) );
	scribbler_merge_value( $css['global'][ $sidebar_title ], Scribbler_Sanitize::padding( scribbler_get_settings( 'sidebar_title_styling_padding' ) ) );
	scribbler_merge_value( $css['global'][ $sidebar_title ], Scribbler_Sanitize::margin( scribbler_get_settings( 'sidebar_title_styling_margin' ) ) );

	// Sidebar Title border.
	$sidebar_title_border = Scribbler_Sanitize::border( scribbler_get_settings( 'widget_title_border' ) );
	$css['global'][ $sidebar_title ][ $sidebar_title_border['direction'] ] = $sidebar_title_border['value'];
	$sidebar_buttons = array(
		'.sidebar #wp-subscribe input.submit',
		'.sidebar .instagram-button a',
	);
	$css['global'][ scribbler_implode( $sidebar_buttons ) ]['border-radius'] = Scribbler_Sanitize::size( scribbler_get_settings( 'sidebar_button_border_radius' ) . 'px' );
	if ( empty( scribbler_get_settings( 'sidebar_top_button_border_radius' ) ) ) :
		$css['global'][ scribbler_implode( $sidebar_buttons ) ]['border-top-left-radius']  = '0px';
		$css['global'][ scribbler_implode( $sidebar_buttons ) ]['border-top-right-radius'] = '0px';
	endif;

}

/**
 * Pages Titles CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function scribbler_pages_title( &$css ) {

	// Background.
	$css['global']['.pages-title-section'] = Scribbler_Sanitize::background( scribbler_get_settings( 'pages_title_background' ) );

	// Padding and Margin.
	scribbler_merge_value( $css['global']['.pages-title-section'], Scribbler_Sanitize::padding( scribbler_get_settings( 'pages_title_padding' ) ) );
	scribbler_merge_value( $css['global']['.pages-title-section'], Scribbler_Sanitize::margin( scribbler_get_settings( 'pages_title_margin' ) ) );

	// Typography.
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'blog_title_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'blog_subtitle_font' ) ) );
	$css['global']['.blog-icon']['background']     = Scribbler_Sanitize::color( scribbler_get_settings( 'blog_icon_bg' ) );
	$css['global']['.blog-icon']['color']          = Scribbler_Sanitize::color( scribbler_get_settings( 'blog_icon_color' ) );
	$css['global']['.blog-svg svg path']['stroke'] = Scribbler_Sanitize::color( scribbler_get_settings( 'arrow_icon_color' ) );

}

/**
 * Layout CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function scribbler_post_layouts( &$css ) {

	// Post Layouts.
	$features = scribbler_get_settings( 'featured_categories' );
	foreach ( $features as $feature ) :

		if ( ! isset( $feature['unique_id'] ) ) {
			continue;
		}

		$category     = $feature['mts_featured_category'];
		$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : 'layout-default';
		$unique_id    = $feature['unique_id'];

		if ( 'layout-default' === $posts_layout ) :
			$posts_layout = 'default';
		endif;

		// Section title align.
		$post_title_align = scribbler_get_settings( 'post_title_alignment_' . $unique_id );

		// Post area.
		$cat_class = 'cat-latest';
		if ( 'latest' !== $category ) {
			$category  = get_term_by( 'slug', $category, 'category' );
			$cat_class = sanitize_key( $category->name );
		}

		$title_class = '.title-container.title-id-' . $unique_id . ' h3';

		$css['global'][ $title_class ] = Scribbler_Sanitize::background( scribbler_get_settings( 'featured_category_title_background_' . $unique_id ) );
		scribbler_merge_value( $css['global'][ $title_class ], Scribbler_Sanitize::margin( scribbler_get_settings( 'featured_category_title_margin_' . $unique_id ) ) );
		scribbler_merge_value( $css['global'][ $title_class ], Scribbler_Sanitize::padding( scribbler_get_settings( 'featured_category_title_padding_' . $unique_id ) ) );
		// Section title border.
		$post_title_border = Scribbler_Sanitize::border( scribbler_get_settings( 'post_title_border_' . $unique_id ) );
		$css['global'][ $title_class ][ $post_title_border['direction'] ] = $post_title_border['value'];

		// Title alignment.
		$align_class = '.title-container.title-id-' . $unique_id;
		if ( 'center' === $post_title_align ) :
			$css['global'][ $align_class ]['text-align'] = 'center';
		elseif ( 'right' === $post_title_align ) :
			$css['global'][ $align_class ]['text-align']              = 'right';
			$css['global'][ $align_class . ' + .view-more' ]['left']  = '0';
			$css['global'][ $align_class . ' + .view-more' ]['right'] = 'auto';
		endif;

		scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'featured_category_title_font_' . $unique_id ) ) );

		if ( 'layout-default' === $posts_layout ) {
			$post_class = '.layout-' . $unique_id . '.default-container';
		} else {
			$post_class = '.layout-' . $unique_id;
		}

		// Post border.
		$post_border = Scribbler_Sanitize::border( scribbler_get_settings( 'post_border_' . $unique_id ) );
		$css['global'][ $post_class ][ $post_border['direction'] ] = $post_border['value'];

		/**
		 * Meta info
		 */
		scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'meta_info_font_' . $unique_id ) ) );
		scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'post_title_font_' . $unique_id ) ) );
		scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'post_excerpt_font_' . $unique_id ) ) );

		if ( 'default' === $posts_layout ) {
			scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'post_categories_font_' . $unique_id ) ) );
			$css['global'][ $post_class . ' .thecategory a' ]['background-color']       = Scribbler_Sanitize::color( scribbler_get_settings( 'post_categories_bg_' . $unique_id ) );
			$css['global'][ $post_class . ' .thecategory a:hover' ]['background-color'] = Scribbler_Sanitize::color( scribbler_get_settings( 'post_categories_hover_bg_' . $unique_id ) );
			scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'meta_info_upper_font_' . $unique_id ) ) );
			scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'meta_info_bottom_font_' . $unique_id ) ) );
		}

		if ( 'layout-1' === $posts_layout ) {
			$css['global'][ $post_class . ' .thecategory a' ]['color'] = Scribbler_Sanitize::color( scribbler_get_settings( 'post_categories_color_' . $unique_id ) );
		}
		scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'readmore_font_' . $unique_id ) ) );

		// Border.
		$meta_info_border = Scribbler_Sanitize::border( scribbler_get_settings( 'meta_info_border_' . $unique_id ) );
		$css['global'][ '.layout-' . $unique_id . ' .latestPost .post-info' ][ $meta_info_border['direction'] ] = $meta_info_border['value'];

		// All Posts Margin and Padding.
		scribbler_merge_value( $css['global'][ $post_class ], Scribbler_Sanitize::margin( scribbler_get_settings( 'post_margin_' . $unique_id ) ) );
		scribbler_merge_value( $css['global'][ $post_class ], Scribbler_Sanitize::padding( scribbler_get_settings( 'post_padding_' . $unique_id ) ) );

	endforeach;
}

/**
 * Pagination
 *
 * @param array $css Array of dynamic CSS.
 */
function scribbler_post_pagination( &$css ) {

	// Pagination Active class.
	$pagination_class_active = array(
		'.pace .pace-progress',
		'.page-numbers.current',
		'.pagination a:hover',
		'#mobile-menu-wrapper ul li a:hover',
		'#load-posts a:hover',
	);
	$pagination_class        = array(
		'.pagination a',
		'#load-posts a',
		'.single .pagination > .current .currenttext',
		'.pagination .page-numbers.dots',
		'.page-numbers.current',
	);
	if ( '2' !== scribbler_get_settings( 'mts_pagenavigation_type' ) ) {
		$css['global'][ scribbler_implode( $pagination_class ) ]['background-color']        = Scribbler_Sanitize::color( scribbler_get_settings( 'mts_pagenavigation_bgcolor' ) );
		$css['global'][ scribbler_implode( $pagination_class_active ) ]['background-color'] = Scribbler_Sanitize::color( scribbler_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );
		$css['global'][ scribbler_implode( $pagination_class ) ]['color']                   = Scribbler_Sanitize::color( scribbler_get_settings( 'mts_pagenavigation_color' ) );
		$css['global'][ scribbler_implode( $pagination_class_active ) ]['color']            = Scribbler_Sanitize::color( scribbler_get_settings( 'mts_pagenavigation_hover_color' ) );
		$css['global'][ scribbler_implode( $pagination_class_active ) ]['border-color']     = Scribbler_Sanitize::color( scribbler_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );
		scribbler_merge_value( $css['global'][ scribbler_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Scribbler_Sanitize::margin( scribbler_get_settings( 'mts_pagenavigation_margin' ) ) );
		scribbler_merge_value( $css['global'][ scribbler_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Scribbler_Sanitize::padding( scribbler_get_settings( 'mts_pagenavigation_padding' ) ) );
		$css['global'][ scribbler_implode( $pagination_class ) ]['min-width']          = Scribbler_Sanitize::size( scribbler_get_settings( 'mts_pagenavigation_width' ) . 'px' );
		$css['global'][ scribbler_implode( $pagination_class_active ) ]['min-width']   = Scribbler_Sanitize::size( scribbler_get_settings( 'mts_pagenavigation_width' ) . 'px' );
		$css['global'][ scribbler_implode( $pagination_class ) ]['line-height']        = Scribbler_Sanitize::size( scribbler_get_settings( 'mts_pagenavigation_height' ) . 'px' );
		$css['global'][ scribbler_implode( $pagination_class_active ) ]['line-height'] = Scribbler_Sanitize::size( scribbler_get_settings( 'mts_pagenavigation_height' ) . 'px' );
		// Pagination border.
		$pagination_border = Scribbler_Sanitize::border( scribbler_get_settings( 'pagenavigation_border' ) );
		$css['global'][ scribbler_implode( $pagination_class ) ][ $pagination_border ['direction'] ] = $pagination_border ['value'];
		$pagination_hover_border = Scribbler_Sanitize::border( scribbler_get_settings( 'pagenavigation_hover_border' ) );
		$css['global'][ scribbler_implode( $pagination_class_active ) ][ $pagination_hover_border ['direction'] ] = $pagination_hover_border ['value'];
		$css['global'][ scribbler_implode( $pagination_class ) ]['border-radius']                                 = Scribbler_Sanitize::size( scribbler_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );
		$css['global'][ scribbler_implode( $pagination_class_active ) ]['border-radius']                          = Scribbler_Sanitize::size( scribbler_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );
	} else {
		$css['global'][ scribbler_implode( $pagination_class ) ]['background-color']        = Scribbler_Sanitize::color( scribbler_get_settings( 'load_more_bgcolor' ) );
		$css['global'][ scribbler_implode( $pagination_class_active ) ]['background-color'] = Scribbler_Sanitize::color( scribbler_get_settings( 'load_more_hover_bgcolor' ) );
		$css['global'][ scribbler_implode( $pagination_class ) ]['color']                   = Scribbler_Sanitize::color( scribbler_get_settings( 'load_more_color' ) );
		$css['global'][ scribbler_implode( $pagination_class_active ) ]['color']            = Scribbler_Sanitize::color( scribbler_get_settings( 'load_more_hover_color' ) );
		scribbler_merge_value( $css['global'][ scribbler_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Scribbler_Sanitize::padding( scribbler_get_settings( 'load_more_padding' ) ) );
		scribbler_merge_value( $css['global'][ scribbler_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Scribbler_Sanitize::margin( scribbler_get_settings( 'load_more_margin' ) ) );
		$css['global'][ scribbler_implode( $pagination_class_active ) ]['border-color'] = Scribbler_Sanitize::color( scribbler_get_settings( 'load_more_hover_bgcolor' ) );
		// Load More border.
		$load_more_border = Scribbler_Sanitize::border( scribbler_get_settings( 'load_more_border' ) );
		$css['global'][ scribbler_implode( $pagination_class ) ][ $load_more_border ['direction'] ] = $load_more_border ['value'];
		$css['global'][ scribbler_implode( $pagination_class ) ]['border-radius']                   = Scribbler_Sanitize::size( scribbler_get_settings( 'load_more_border_radius' ) . 'px' );
		$css['global'][ scribbler_implode( $pagination_class_active ) ]['border-radius']            = Scribbler_Sanitize::size( scribbler_get_settings( 'load_more_border_radius' ) . 'px' );
	}

	// Load more Alignment.
	$load_more_align = scribbler_get_settings( 'load_more_alignment' );
	if ( 'left' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'left';
	elseif ( 'right' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'right';
	elseif ( 'full' === $load_more_align ) :
		$css['global']['#load-posts a']['width'] = '100%';
	endif;
}

/**
 * Single
 *
 * @param array $css Array of dynamic CSS.
 */
function scribbler_single( &$css ) {

	// Single Page auto padding.
	$single_padding = Scribbler_Sanitize::padding( scribbler_get_settings( 'mts_single_styling_padding' ) );

	$css['global']['.single-featured-wrap']['margin-top']   = '-' . $single_padding['padding-top'];
	$css['global']['.single-featured-wrap']['margin-right'] = '-' . $single_padding['padding-right'];
	$css['global']['.single-featured-wrap']['margin-left']  = '-' . $single_padding['padding-left'];

	// Single, Page and 404 Page Background.
	$page_classes = array(
		'.single_post',
		'.page .article',
		'.error404 .article',
	);

	$css['global'][ scribbler_implode( $page_classes ) ] = Scribbler_Sanitize::background( scribbler_get_settings( 'single_background' ) );

	// Margin, Padding, Border and Box Shadow.
	scribbler_merge_value( $css['global']['.article'], Scribbler_Sanitize::margin( scribbler_get_settings( 'mts_single_styling_margin' ) ) );
	scribbler_merge_value( $css['global'][ scribbler_implode( $page_classes ) ], Scribbler_Sanitize::padding( scribbler_get_settings( 'mts_single_styling_padding' ) ) );

	// Single border.
	$single_border = Scribbler_Sanitize::border( scribbler_get_settings( 'single_styling_border' ) );
	$css['global']['.article'][ $single_border ['direction'] ] = $single_border ['value'];

	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'single_post_author_meta_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'single_post_date_meta_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'single_post_categories_font' ) ) );
	$css['global']['.single_post .post-info .thecategory a']['background-color']       = Scribbler_Sanitize::color( scribbler_get_settings( 'single_post_categories_bg' ) );
	$css['global']['.single_post .post-info .thecategory a:hover']['background-color'] = Scribbler_Sanitize::color( scribbler_get_settings( 'single_post_categories_hover_bg' ) );
	// Tags.
	$css['global']['.tags a, .tagcloud a, .widget .wpt_widget_content #tags-tab-content ul li a']['background-color'] = Scribbler_Sanitize::color( scribbler_get_settings( 'tags_bgcolor' ) );

	// Author Posts.
	$css['global']['.single-author-posts'] = Scribbler_Sanitize::background( scribbler_get_settings( 'authorpost_background' ) );

	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'authorpost_title_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'authorpost_categories_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'authorpost_meta_font' ) ) );

	scribbler_merge_value( $css['global']['.single-author-posts'], Scribbler_Sanitize::margin( scribbler_get_settings( 'authorpost_margin' ) ) );
	scribbler_merge_value( $css['global']['.single-author-posts'], Scribbler_Sanitize::padding( scribbler_get_settings( 'authorpost_padding' ) ) );
	if ( empty( scribbler_get_settings( 'author_box_shadow' ) ) ) :
		$css['global']['.postauthor']['box-shadow'] = 'none';
	endif;

	// Related Posts.
	$css['global']['.related-posts'] = Scribbler_Sanitize::background( scribbler_get_settings( 'related_posts_background' ) );

	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'related_posts_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'related_posts_categories_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'related_posts_meta_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'related_posts_text_font' ) ) );
	$css['global']['.related-posts .thecategory a']['color'] = Scribbler_Sanitize::color( scribbler_get_settings( 'related_posts_categories_color' ) );

	scribbler_merge_value( $css['global']['.related-posts'], Scribbler_Sanitize::margin( scribbler_get_settings( 'related_posts_margin' ) ) );
	scribbler_merge_value( $css['global']['.related-posts'], Scribbler_Sanitize::padding( scribbler_get_settings( 'related_posts_padding' ) ) );

	$related_posts_border = Scribbler_Sanitize::border( scribbler_get_settings( 'related_posts_border' ) );
	$css['global']['.related-posts'][ $related_posts_border ['direction'] ] = $related_posts_border ['value'];

	// Related Posts articles.
	$css['global']['.related-posts article'] = Scribbler_Sanitize::background( scribbler_get_settings( 'related_article_background' ) );
	scribbler_merge_value( $css['global']['.related-posts article'], Scribbler_Sanitize::padding( scribbler_get_settings( 'related_article_padding' ) ) );

	// Subscribe Box.
	$css['global']['.single-subscribe .widget.wp_subscribe'] = Scribbler_Sanitize::background( scribbler_get_settings( 'single_subscribe_background' ) );
	scribbler_merge_value( $css['global']['.single-subscribe .widget.wp_subscribe'], Scribbler_Sanitize::margin( scribbler_get_settings( 'single_subscribe_margin' ) ) );
	scribbler_merge_value( $css['global']['.single-subscribe .widget.wp_subscribe'], Scribbler_Sanitize::padding( scribbler_get_settings( 'single_subscribe_padding' ) ) );
	$css['global']['.single-subscribe .widget.wp_subscribe']['border-radius'] = Scribbler_Sanitize::size( scribbler_get_settings( 'single_subscribe_border_radius' ) . 'px' );
	if ( empty( scribbler_get_settings( 'single_subscribe_image' ) ) ) :
		$css['global']['.single-subscribe .widget.wp_subscribe:before']['display'] = 'none';
	endif;
	// Subscribe border.
	$subscribe_border = Scribbler_Sanitize::border( scribbler_get_settings( 'single_subscribe_border' ) );
	$css['global']['.single-subscribe .widget.wp_subscribe'][ $subscribe_border ['direction'] ] = $subscribe_border ['value'];

	// Subscribe Box Input fields.
	$subscribe_input_class = array(
		'.single-subscribe #wp-subscribe input.email-field',
		'.single-subscribe #wp-subscribe input.name-field',
	);
	$css['global'][ scribbler_implode( $subscribe_input_class ) ]['background-color'] = Scribbler_Sanitize::color( scribbler_get_settings( 'single_subscribe_input_background' ) );
	$css['global'][ scribbler_implode( $subscribe_input_class ) ]['height']           = Scribbler_Sanitize::size( scribbler_get_settings( 'single_subscribe_input_height' ) . 'px' );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['height']  = Scribbler_Sanitize::size( scribbler_get_settings( 'single_subscribe_input_height' ) . 'px' );
	$css['global'][ scribbler_implode( $subscribe_input_class ) ]['border-radius']    = Scribbler_Sanitize::size( scribbler_get_settings( 'single_subscribe_input_border_radius' ) . 'px' );

	// Subscribe Box Input border.
	$subscribe_box_input_border = Scribbler_Sanitize::border( scribbler_get_settings( 'single_subscribe_input_border' ) );
	$css['global'][ scribbler_implode( $subscribe_input_class ) ][ $subscribe_box_input_border ['direction'] ] = $subscribe_box_input_border ['value'];

	// Subscribe Box Submit button.
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['background']    = Scribbler_Sanitize::color( scribbler_get_settings( 'single_subscribe_submit_backgroud' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['border-radius'] = Scribbler_Sanitize::size( scribbler_get_settings( 'single_subscribe_submit_border_radius' ) . 'px' );

	// Subscribe Box Submit border.
	$subscribe_box_submit_border = Scribbler_Sanitize::border( scribbler_get_settings( 'single_subscribe_submit_border' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit'][ $subscribe_box_submit_border ['direction'] ] = $subscribe_box_submit_border ['value'];

	scribbler_merge_value( $css['global']['.single-subscribe .widget #wp-subscribe input.submit'], Scribbler_Sanitize::padding( scribbler_get_settings( 'single_subscribe_submit_padding' ) ) );

	// Author Box.
	$css['global']['.postauthor'] = Scribbler_Sanitize::background( scribbler_get_settings( 'authorbox_background' ) );

	scribbler_merge_value( $css['global']['.postauthor'], Scribbler_Sanitize::margin( scribbler_get_settings( 'authorbox_margin' ) ) );

	scribbler_merge_value( $css['global']['.postauthor'], Scribbler_Sanitize::padding( scribbler_get_settings( 'authorbox_padding' ) ) );

	$css['global']['.postauthor']['border-radius'] = Scribbler_Sanitize::size( scribbler_get_settings( 'authorbox_border_radius' ) . 'px' );

	$authorbox_border = Scribbler_Sanitize::border( scribbler_get_settings( 'authorbox_border' ) );
	$css['global']['.postauthor'][ $authorbox_border ['direction'] ] = $authorbox_border ['value'];

	// Author image.
	scribbler_merge_value( $css['global']['.postauthor img'], Scribbler_Sanitize::margin( scribbler_get_settings( 'single_author_image_margin' ) ) );

	$css['global']['.postauthor img']['border-radius'] = Scribbler_Sanitize::size( scribbler_get_settings( 'single_author_image_border_radius' ) . 'px' );

	// Single Page titles Styling.
	$titles_align = scribbler_get_settings( 'single_title_alignment' );

	$titles_align_class = array(
		'.comment-title',
		'#respond',
		'.related-posts-title',
	);
	$titles_class       = array(
		'#respond h3',
		'#respond h4',
		'.total-comments',
		'.related-posts h4',
	);

	$css['global'][ scribbler_implode( $titles_class ) ] = Scribbler_Sanitize::background( scribbler_get_settings( 'single_title_background' ) );
	scribbler_merge_value( $css['global'][ scribbler_implode( $titles_class ) ], Scribbler_Sanitize::padding( scribbler_get_settings( 'single_title_padding' ) ) );
	// Single title border.
	$single_titles_border = Scribbler_Sanitize::border( scribbler_get_settings( 'single_title_border' ) );
	$css['global'][ scribbler_implode( $titles_class ) ][ $single_titles_border ['direction'] ] = $single_titles_border ['value'];

	if ( 'left' === $titles_align ) :
		$css['global'][ scribbler_implode( $titles_class ) ]['display'] = 'inline-block';
	elseif ( 'center' === $titles_align ) :
		$css['global'][ scribbler_implode( $titles_align_class ) ]['text-align'] = 'center';
		$css['global'][ scribbler_implode( $titles_class ) ]['display']          = 'inline-block';
	elseif ( 'right' === $titles_align ) :
		$css['global'][ scribbler_implode( $titles_align_class ) ]['text-align'] = 'right';
		$css['global'][ scribbler_implode( $titles_class ) ]['display']          = 'inline-block';
	endif;

}

/**
 * Copyrights
 *
 * @param array $css Array of dynamic CSS.
 */
function scribbler_copyrights( &$css ) {
	$css['global']['.copyrights'] = Scribbler_Sanitize::background( scribbler_get_settings( 'mts_copyrights_background' ) );
	scribbler_merge_value( $css['global']['.copyrights'], Scribbler_Sanitize::margin( scribbler_get_settings( 'copyrights_margin' ) ) );
	scribbler_merge_value( $css['global']['.copyrights'], Scribbler_Sanitize::padding( scribbler_get_settings( 'copyrights_padding' ) ) );
	// copyrights border.
	$copyrights_border = Scribbler_Sanitize::border( scribbler_get_settings( 'copyrights_border' ) );
	$css['global']['.copyrights'][ $copyrights_border ['direction'] ] = $copyrights_border ['value'];

}

/**
 * Footer
 *
 * @param array $css Array of dynamic CSS.
 */
function scribbler_footer( &$css ) {

	// Footer.
	if ( scribbler_get_settings( 'mts_top_footer' ) ) {
		scribbler_merge_value( $css['global']['#site-footer'], Scribbler_Sanitize::margin( scribbler_get_settings( 'mts_top_footer_margin' ) ) );
		scribbler_merge_value( $css['global']['#site-footer'], Scribbler_Sanitize::padding( scribbler_get_settings( 'mts_top_footer_padding' ) ) );
	}

}

/**
 * Archive
 *
 * @param array $css Array of dynamic CSS.
 */
function scribbler_archive_post( &$css ) {

	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'archive_post_title_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'archive_post_excerpt_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'archive_categories_font' ) ) );
	scribbler_map_css_selectors( $css['global'], Scribbler_Sanitize::typography( scribbler_get_settings( 'archive_meta_info_font' ) ) );

}

/**
 * Misc
 *
 * @param array $css Array of dynamic CSS.
 */
function scribbler_misc_css( &$css ) {

	// Nav hover color position.
	$padding        = Scribbler_Sanitize::padding( scribbler_get_settings( 'header_padding' ) );
	$padding_bottom = (int) $padding['padding-bottom'];

	// Show Logo.
	$show_logo = scribbler_get_settings( 'hide_logo' );

	if ( 0 === $show_logo ) {
		$css['global']['.logo-wrap']['display'] = 'none';
	}

	// Back to top.
	// Border.
	$top_button_border = Scribbler_Sanitize::border( scribbler_get_settings( 'top_button_border' ) );
	$css['global']['#move-to-top'][ $top_button_border ['direction'] ] = $top_button_border ['value'];
	// Font-size, Padding and Position.
	$css['global']['#move-to-top .fa']['font-size'] = Scribbler_Sanitize::size( scribbler_get_settings( 'top_button_font_size' ) . 'px' );
	scribbler_merge_value( $css['global']['#move-to-top'], Scribbler_Sanitize::padding( scribbler_get_settings( 'top_button_padding' ) ) );
	$top_button_position = scribbler_get_settings( 'top_button_position' );
	foreach ( $top_button_position as $key => $position ) {
		$css['global']['#move-to-top'][ $key ] = $position;
	}
	// Border-radius.
	$css['global']['#move-to-top']['border-radius'] = Scribbler_Sanitize::size( scribbler_get_settings( 'top_button_border_radius' ) . 'px' );
	// Colors.
	$css['global']['#move-to-top']['color']            = Scribbler_Sanitize::color( scribbler_get_settings( 'top_button_color' ) );
	$css['global']['#move-to-top:hover']['color']      = Scribbler_Sanitize::color( scribbler_get_settings( 'top_button_color_hover' ) );
	$css['global']['#move-to-top']['background']       = Scribbler_Sanitize::color( scribbler_get_settings( 'top_button_background' ) );
	$css['global']['#move-to-top:hover']['background'] = Scribbler_Sanitize::color( scribbler_get_settings( 'top_button_background_hover' ) );

	// Full width Related Posts.
	if ( 'full' === scribbler_get_settings( 'related_posts_position' ) ) {
		$css['global']['.single .article']['margin-bottom'] = '0px';
	}

	// widgets margin
	$widgets_margin = Scribbler_Sanitize::padding( scribbler_get_settings( 'sidebar_styling_padding' ) );
	$elements       = array(
		'.sidebar .widget.instagram-widget-wrapper .instagram-posts',
		'.sidebar .widget .wpt-tabs',
		'.sidebar .widget .wp-review-tabs',
		'.sidebar .widget.widget_categories li',
		'.sidebar .widget.widget_archive li',
		'.sidebar .widget.widget_pages li',
		'.sidebar .widget.widget_meta li',
		'.sidebar .widget.widget_recent_comments li',
		'.sidebar .widget.widget_recent_entries li',
		'.sidebar .widget.widget_rss li',
		'.sidebar .widget.widget_nav_menu li',
		'.sidebar #wp-subscribe input.submit',
		'.sidebar .instagram-button',
	);
	$css['global'][ scribbler_implode( $elements ) ]['margin-left']  = '-' . $widgets_margin['padding-left'];
	$css['global'][ scribbler_implode( $elements ) ]['margin-right'] = '-' . $widgets_margin['padding-right'];

	$elements = array(
		'.sidebar .widget.widget_categories li',
		'.sidebar .widget.widget_archive li',
		'.sidebar .widget.widget_pages li',
		'.sidebar .widget.widget_meta li',
		'.sidebar .widget.widget_recent_comments li',
		'.sidebar .widget.widget_recent_entries li',
		'.sidebar .widget.widget_rss li',
		'.sidebar .widget.widget_nav_menu li',
	);

	$css['global'][ scribbler_implode( $elements ) ]['padding-left']  = $widgets_margin['padding-left'];
	$css['global'][ scribbler_implode( $elements ) ]['padding-right'] = $widgets_margin['padding-right'];

	$elements = array(
		'.sidebar #wp-subscribe input.submit',
		'.sidebar .instagram-button',
	);
	//total width
	$width = (int) $widgets_margin['padding-left'] + (int) $widgets_margin['padding-right'] . 'px';
	$css['global'][ scribbler_implode( $elements ) ]['width'] = 'calc( 100% + ' . $width . ' )';

}
